@@ -16,6 +16,7 @@
 #include "kdeconnect-version.h"
 #include <KAboutData>
 #include <KColorSchemeManager>
+#include <KCrash>
 #include <KLocalizedContext>
 #include <KLocalizedString>
 
@@ -37,6 +38,8 @@ int main(int argc, char *argv[])
     aboutData.setBugAddress("https://bugs.kde.org/enter_bug.cgi?product=kdeconnect&component=common");
     KAboutData::setApplicationData(aboutData);
 
+    KCrash::initialize();
+
 #ifdef Q_OS_WIN
     KColorSchemeManager manager;
     QApplication::setStyle(QStringLiteral("breeze"));
