@@ -81,12 +81,7 @@ void BluetoothLinkProvider::connectError()
 
     disconnect(socket, &QBluetoothSocket::connected, this, nullptr);
     disconnect(socket, &QBluetoothSocket::readyRead, this, nullptr);
-
-#if QT_VERSION_MAJOR == 5
-    disconnect(socket, QOverload<QBluetoothSocket::SocketError>::of(&QBluetoothSocket::error), this, nullptr);
-#else
     disconnect(socket, QOverload<QBluetoothSocket::SocketError>::of(&QBluetoothSocket::errorOccurred), this, nullptr);
-#endif
 
     mSockets.remove(socket->peerAddress());
     socket->deleteLater();
@@ -94,6 +89,8 @@ void BluetoothLinkProvider::connectError()
 
 void BluetoothLinkProvider::addLink(BluetoothDeviceLink *deviceLink, const QString &deviceId)
 {
+    Q_EMIT onConnectionReceived(deviceLink);
+
     qCDebug(KDECONNECT_CORE) << "BluetoothLinkProvider::addLink executed";
     if (mLinks.contains(deviceId)) {
         delete mLinks.take(deviceId); // not calling deleteLater because this triggers onLinkDestroyed
@@ -129,11 +126,7 @@ void BluetoothLinkProvider::serviceDiscovered(const QBluetoothServiceInfo &old_i
     });
 
     qCDebug(KDECONNECT_CORE) << "BluetoothLinkProvider::serviceDiscovered about to call connect";
-#if QT_VERSION_MAJOR == 5
-    connect(socket, QOverload<QBluetoothSocket::SocketError>::of(&QBluetoothSocket::error), this, &BluetoothLinkProvider::connectError);
-#else
     connect(socket, QOverload<QBluetoothSocket::SocketError>::of(&QBluetoothSocket::errorOccurred), this, &BluetoothLinkProvider::connectError);
-#endif
 
     qCDebug(KDECONNECT_CORE) << "BluetoothLinkProvider::serviceDiscovered about to call connectToService";
 
@@ -201,8 +194,8 @@ void BluetoothLinkProvider::clientIdentityReceived(const QBluetoothAddress &peer
     NetworkPacket receivedPacket;
     bool success = NetworkPacket::unserialize(identityArray, &receivedPacket);
 
-    if (!success || receivedPacket.type() != PACKET_TYPE_IDENTITY) {
-        qCWarning(KDECONNECT_CORE) << "BluetoothLinkProvider Received not an identity packet";
+    if (!success || !DeviceInfo::isValidIdentityPacket(&receivedPacket)) {
+        qCWarning(KDECONNECT_CORE) << "BluetoothLinkProvider: Invalid identity packet received";
         mSockets.remove(peer);
         socket->close();
         socket->deleteLater();
@@ -226,8 +219,6 @@ void BluetoothLinkProvider::clientIdentityReceived(const QBluetoothAddress &peer
     if (success) {
         qCDebug(KDECONNECT_CORE) << "BluetoothLinkProvider Handshaking done (I'm the new device)";
 
-        Q_EMIT onConnectionReceived(deviceLink);
-
         // We kill any possible link from this same device
         addLink(deviceLink, deviceInfo.id);
 
@@ -307,8 +298,8 @@ void BluetoothLinkProvider::serverDataReceived(const QBluetoothAddress &peer, QS
     NetworkPacket receivedPacket;
     bool success = NetworkPacket::unserialize(identityArray, &receivedPacket);
 
-    if (!success || receivedPacket.type() != PACKET_TYPE_IDENTITY) {
-        qCWarning(KDECONNECT_CORE) << "Not an identity packet.";
+    if (!success || !DeviceInfo::isValidIdentityPacket(&receivedPacket)) {
+        qCWarning(KDECONNECT_CORE) << "BluetoothLinkProvider: Invalid identity packet received";
         mSockets.remove(peer);
         socket->close();
         socket->deleteLater();
@@ -321,8 +312,6 @@ void BluetoothLinkProvider::serverDataReceived(const QBluetoothAddress &peer, QS
     DeviceInfo deviceInfo = deviceInfo.FromIdentityPacketAndCert(receivedPacket, receivedCertificate);
     BluetoothDeviceLink *deviceLink = new BluetoothDeviceLink(deviceInfo, this, mSockets[peer], socket);
 
-    Q_EMIT onConnectionReceived(deviceLink);
-
     addLink(deviceLink, deviceInfo.id);
 }
 
