@@ -34,9 +34,6 @@ public:
         windowFlags |= Qt::WindowTransparentForInput;
 #endif
         setFlags(windowFlags);
-#if QT_VERSION_MAJOR < 6
-        setClearBeforeRendering(true);
-#endif
         setColor(QColor(Qt::transparent));
 
         setResizeMode(QQuickView::SizeViewToRootObject);
