@@ -4,13 +4,10 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef SENDNOTIFICATIONSPLUGIN_H
-#define SENDNOTIFICATIONSPLUGIN_H
+#pragma once
 
 #include "core/kdeconnectplugin.h"
 
-#define PACKET_TYPE_NOTIFICATION QStringLiteral("kdeconnect.notification")
-
 /*
  * This class is just a proxy for NotificationsDbusInterface
  * because it can not inherit from QDBusAbstractAdaptor and
@@ -27,11 +24,6 @@ public:
     explicit SendNotificationsPlugin(QObject *parent, const QVariantList &args);
     ~SendNotificationsPlugin() override;
 
-    bool receivePacket(const NetworkPacket &np) override;
-    void connected() override;
-
 protected:
     NotificationsListener *notificationsListener;
 };
-
-#endif
